@@ -25,7 +25,7 @@ from gazpacho.command import CommandManager, CommandStackView
 from gazpacho.clipboard import Clipboard, ClipboardView
 from gazpacho.gaction import GActionsView, GAction, GActionGroup
 from gazpacho.gaction import GActionDialog, GActionGroupDialog
-from gazpacho.widget import Widget
+from gazpacho.widget import Widget, get_widget_from_gtk_widget
 from gazpacho.l10n import _
 
 class Application(object):
@@ -119,20 +119,19 @@ class Application(object):
         main_vbox.pack_start(toolbar, False)
 
         hbox = gtk.HBox(spacing=6)
-        frame = self._create_frame(_('Palette'), self._palette)
-        hbox.pack_start(frame, False, False)
+        hbox.pack_start(self._palette, False, False)
 
         vpaned = gtk.VPaned()
-        hbox.pack_start(vpaned, False, False)
-        
-        frame = self._create_frame(_('Widget Tree'), widget_view)
-        vpaned.add1(frame)
-        
-        frame = self._create_frame(_('Actions'), self.gactions_view)
-        vpaned.add2(frame)
-        
-        frame = self._create_frame(_('Editor'), self._editor)
-        hbox.pack_start(frame, True, True)
+        hbox.pack_start(vpaned, True, True)
+
+        notebook = gtk.Notebook()
+        notebook.append_page(widget_view, gtk.Label(_('Widgets')))
+        notebook.append_page(self.gactions_view, gtk.Label(_('Actions')))
+
+        vpaned.set_position(200)
+
+        vpaned.add1(notebook)
+        vpaned.add2(self._editor)
 
         main_vbox.pack_start(hbox)
         
@@ -199,7 +198,7 @@ class Application(object):
              _('Close Project'), self._close_cb),
             ('Quit', gtk.STOCK_QUIT, _('_Quit'), '<control>Q', _('Quit'),
              self._quit_cb),
-            ('EditMenu', None, '_Edit'),
+            ('EditMenu', None, _('_Edit')),
             ('Cut', gtk.STOCK_CUT, _('C_ut'), '<control>X', _('Cut'),
              self._cut_cb),
             ('Copy', gtk.STOCK_COPY, _('_Copy'), '<control>C', _('Copy'),
@@ -276,7 +275,6 @@ class Application(object):
     </menu>
   </menubar>
   <toolbar name="MainToolbar">
-    <toolitem action="Quit"/>
     <toolitem action="Open"/>
     <toolitem action="Save"/>
     <separator name="MT1"/>
@@ -508,6 +506,7 @@ class Application(object):
                                              gtk.STOCK_SAVE,
                                              gtk.RESPONSE_OK))
         filechooser.set_current_name("%s.glade" % project.name)
+        filechooser.set_default_response(gtk.RESPONSE_OK)
         while True:
             if filechooser.run() == gtk.RESPONSE_OK:
                 path = filechooser.get_filename()
@@ -556,6 +555,7 @@ class Application(object):
         while True:
             ret = dialog.run()
             if ret == gtk.RESPONSE_YES:
+                close = True
                 if project.path:
                     project.save(project.path)
                     close = True
@@ -625,7 +625,7 @@ class Application(object):
     def _real_cut(self):
         selection = self._project.selection
         if selection:
-            gwidget = Widget.get_from_gtk_widget(selection[0])
+            gwidget = get_widget_from_gtk_widget(selection[0])
             self._command_manager.cut(gwidget)
             
     def _cut_cb(self, action):
@@ -634,7 +634,7 @@ class Application(object):
     def _real_copy(self):
         selection = self._project.selection
         if selection:
-            gwidget = Widget.get_from_gtk_widget(selection[0])
+            gwidget = get_widget_from_gtk_widget(selection[0])
             self._command_manager.copy(gwidget)
     
     def _copy_cb(self, action):
@@ -668,7 +668,7 @@ class Application(object):
         image = gtk.Image()
         image.set_from_file(join(pixmaps_dir, 'gazpacho.png'))
 
-        version = gtk.Label('<span size="xx-large"><b>Gazpacho 0.5.0</b></span>')
+        version = gtk.Label('<span size="xx-large"><b>Gazpacho 0.5.2</b></span>')
         version.set_use_markup(True)
         description = gtk.Label(_('Gazpacho is a User Interface Builder for GTK+.\n\n')+'\n\n<small>(C) 2004,2005 SICEm S.L.</small>')
         description.set_use_markup(True)
@@ -705,7 +705,7 @@ class Application(object):
             children = self._project.selection
             if len(children) == 1 and not isinstance(children[0], Placeholder):
                 self._editor.load_widget(
-                    Widget.get_from_gtk_widget(children[0])
+                    get_widget_from_gtk_widget(children[0])
                     )
             else:
                 self._editor.load_widget(None)
