@@ -21,7 +21,7 @@ import os
 
 from gazpacho import util
 from gazpacho.placeholder import Placeholder
-from gazpacho.widget import Widget
+from gazpacho.widget import Widget, get_widget_from_gtk_widget
 from gazpacho.uieditor import UIEditor
 from gazpacho.widgetregistry import widget_registry
 from gazpacho.l10n import _
@@ -61,7 +61,7 @@ def glade_gtk_widget_get_tooltip(widget):
     return None
 
 def glade_gtk_widget_set_tooltip(widget, tooltip):
-    gwidget = Widget.get_from_gtk_widget(widget)
+    gwidget = get_widget_from_gtk_widget(widget)
     tooltips = gwidget.project.tooltips
     if tooltip:
         tooltips.set_tip(widget, tooltip, None)
@@ -87,7 +87,7 @@ def glade_gtk_box_set_size(box, size):
         # The box has shrunk. Remove the widgets that are not on those slots
         child = box.get_children()[-1]
         while old_size > new_size and child:
-            gwidget = Widget.get_from_gtk_widget(child)
+            gwidget = get_widget_from_gtk_widget(child)
             if gwidget: # It may be None, e.g a placeholder
                 gwidget.project.remove_widget(child)
 
@@ -110,7 +110,7 @@ def glade_gtk_notebook_get_n_pages(notebook):
 
 def glade_gtk_notebook_set_n_pages(notebook, pages):
     global app
-    gwidget = Widget.get_from_gtk_widget(notebook)
+    gwidget = get_widget_from_gtk_widget(notebook)
     old_size = notebook.get_n_pages()
     new_size = pages
 
@@ -131,7 +131,7 @@ def glade_gtk_notebook_set_n_pages(notebook, pages):
         # old_size-1, where we're referring to "nth" widget.
         while old_size > new_size:
             child_widget = notebook.get_nth_page(old_size - 1)
-            child_gwidget = Widget.get_from_gtk_widget(child_widget)
+            child_gwidget = get_widget_from_gtk_widget(child_widget)
 
             # If we got it, and it's not a placeholder, remove it from project
             if child_gwidget:
@@ -151,7 +151,7 @@ def glade_gtk_table_set_n_common(table, value, for_rows):
     if new_size < 1:
         return
 
-    gwidget = Widget.get_from_gtk_widget(table)
+    gwidget = get_widget_from_gtk_widget(table)
     if new_size > old_size:
         if for_rows:
             table.resize(new_size, table.get_property('n-columns'))
@@ -234,7 +234,7 @@ def glade_gtk_combo_box_pre_create(combo, interactive=True):
 def glade_gtk_table_post_create(table, interactive=True):
     if not interactive:
         return
-    gwidget = Widget.get_from_gtk_widget(table)
+    gwidget = get_widget_from_gtk_widget(table)
     property_rows = gwidget.get_glade_property('n-rows')
     property_cols = gwidget.get_glade_property('n-columns')
     dialog = gtk.Dialog(_('Create a table'), None,
@@ -250,13 +250,15 @@ def glade_gtk_table_post_create(table, interactive=True):
     label_cols.set_alignment(0.0, 0.5)
 
     spin_button_rows = gtk.SpinButton()
-    spin_button_rows.set_range(0.0, 10000.0)
+    spin_button_rows.set_increments(1, 5)
+    spin_button_rows.set_range(1.0, 10000.0)
     spin_button_rows.set_numeric(False)
     spin_button_rows.set_value(3)
     spin_button_rows.set_property('activates-default', True)
     
     spin_button_cols = gtk.SpinButton()
-    spin_button_cols.set_range(0.0, 10000.0)
+    spin_button_cols.set_increments(1, 5)
+    spin_button_cols.set_range(1.0, 10000.0)
     spin_button_cols.set_numeric(False)
     spin_button_cols.set_value(3)
     spin_button_cols.set_property('activates-default', True)
@@ -446,7 +448,7 @@ def glade_gtk_image_icon_size_editor_load(editor, image, proxy):
 ### GtkDialog
 def glade_gtk_dialog_post_create(dialog, interactive=True):
     global app
-    gwidget = Widget.get_from_gtk_widget(dialog)
+    gwidget = get_widget_from_gtk_widget(dialog)
     if not gwidget: return
 
     # create the GladeWidgets for internal children
@@ -454,9 +456,8 @@ def glade_gtk_dialog_post_create(dialog, interactive=True):
     if not child_class: return
 
     project = gwidget.project
-    vbox_widget = Widget(child_class, project,
-                         internal_widget=dialog.vbox,
-                         internal_name='vbox')
+    vbox_widget = Widget(child_class, project)
+    vbox_widget.setup_internal_widget(dialog.vbox, 'vbox', gwidget.name)
 
     child_class = widget_registry.get_by_name('GtkHButtonBox')
     if not child_class: return
@@ -464,9 +465,10 @@ def glade_gtk_dialog_post_create(dialog, interactive=True):
     dialog.action_area.pack_start(Placeholder(app))
     dialog.action_area.pack_start(Placeholder(app))
 
-    action_area_widget = Widget(child_class, project,
-                                internal_widget=dialog.action_area,
-                                internal_name='action_area')
+    action_area_widget = Widget(child_class, project)
+    action_area_widget.setup_internal_widget(dialog.action_area,
+                                             'action_area',
+                                             gwidget.name)
 
     # set a reasonable default size for a dialog
     dialog.set_default_size(320, 260)
@@ -522,10 +524,29 @@ def glade_gtk_dialog_fill_empty(dialog):
     global app
     dialog.vbox.pack_start(Placeholder(app))
 
+def _glade_gtk_paned_set_position(paned):
+    """This function get called until the paned is realized.
+    Then it puts the bar in the middle.
+    """
+    if paned.flags() & gtk.REALIZED:
+        alloc = paned.get_allocation()
+        if isinstance(paned, gtk.VPaned):
+            pos = alloc.height / 2
+        else:
+            pos = alloc.width / 2
+        paned.set_position(pos)
+        return False
+    else:
+        return True
+    
 def glade_gtk_paned_fill_empty(paned):
     global app
     paned.add1(Placeholder(app))
     paned.add2(Placeholder(app))
+    # we want to set the position in the middle but
+    # as the paned has not yet a parent it is not
+    # realized we can't know its size
+    gobject.idle_add(_glade_gtk_paned_set_position, paned)
 
 # Get internal child functions
 def glade_gtk_dialog_get_internal_child(dialog, name):
@@ -569,7 +590,7 @@ def _create_default_actions(gaction_group, project):
             app._command_manager.add_action(values, gaction_group, project)
 
 def glade_gtk_menu_bar_post_create(menubar, interactive=True):
-    gwidget = Widget.get_from_gtk_widget(menubar)
+    gwidget = get_widget_from_gtk_widget(menubar)
     # A None in this list means a separator
     names = [gwidget.name, _('FileMenu'), _('New'), _('Open'), _('Save'),
              _('SaveAs'), None, _('Quit'), _('EditMenu'), _('Copy'), _('Cut'),
@@ -603,7 +624,7 @@ def glade_gtk_menu_bar_post_create(menubar, interactive=True):
 
 
 def glade_gtk_tool_bar_post_create(toolbar, interactive=True):
-    gwidget = Widget.get_from_gtk_widget(toolbar)
+    gwidget = get_widget_from_gtk_widget(toolbar)
 
     # None in this tuple represent a separator
     names = [gwidget.name, _('New'), _('Open'), _('Save'), None,
@@ -632,7 +653,7 @@ def glade_gtk_tool_bar_post_create(toolbar, interactive=True):
 def _internal_menu_or_tool_bar_post_create(widget, ui_string):
     global app
     # create some default actions
-    gwidget = Widget.get_from_gtk_widget(widget)
+    gwidget = get_widget_from_gtk_widget(widget)
     project = gwidget.project
     # look for the 'DefaultActions' action group
     gaction_group = None
@@ -649,8 +670,9 @@ def _internal_menu_or_tool_bar_post_create(widget, ui_string):
     _create_default_actions(gaction_group, project)
     
     new_widget = _get_new_widget_after_uimanager_change(widget, ui_string)
-    gwidget.widget = new_widget
-
+    gwidget.setup_widget(new_widget)
+    gwidget.apply_properties()
+    
 def glade_gtk_menu_or_tool_bar_ui_editor_create():
     button = gtk.Button(_('Edit...'))
     button.set_data('connection-id', -1)
@@ -673,7 +695,7 @@ def glade_gtk_menu_or_tool_bar_ui_editor_load(button, widget, proxy):
     button.set_data('connection-id', connection_id)
 
 def _get_new_widget_after_uimanager_change(widget, ui_string):
-    gwidget = Widget.get_from_gtk_widget(widget)
+    gwidget = get_widget_from_gtk_widget(widget)
     ui_prop = gwidget.get_glade_property('ui')
     ui_prop.value = ui_string
     project = gwidget.project
@@ -694,7 +716,7 @@ def glade_gtk_menu_or_tool_bar_ui_set(widget, ui_string):
     if not ui_string:
         return
 
-    gwidget = Widget.get_from_gtk_widget(widget)
+    gwidget = get_widget_from_gtk_widget(widget)
     project = gwidget.project
     new_widget = _get_new_widget_after_uimanager_change(widget, ui_string)
     
@@ -712,7 +734,7 @@ def glade_gtk_menu_or_tool_bar_ui_set(widget, ui_string):
         for name, value in props.items():
             container.child_set_property(new_widget, name, value)
 
-        gwidget.widget = new_widget
+        gwidget.setup_widget(new_widget)
         
         project.widgets.remove(widget)
         project.widgets.append(new_widget)
